#[non_exhaustive]pub enum SamplerPreset {
Nearest,
Linear,
Anisotropic,
Comparison,
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Nearest
Nearest-neighbor filtering, clamp to edge. Best for pixel art and textures that should not be interpolated.
Linear
Bilinear filtering, clamp to edge. General-purpose filtering for smooth texture sampling.
Anisotropic
Anisotropic filtering, clamp to edge. Best quality for 3D surfaces viewed at oblique angles. Uses the maximum anisotropy level supported by the device.
Comparison
Comparison sampler for shadow mapping.
Uses LessEqual comparison with linear filtering.